@@ -9,9 +9,10 @@ use Class::Utils qw(set_params);
 use Error::Pure qw(err);
 use Imager;
 use Imager::Fill;
+use List::MoreUtils qw(none);
 
 # Version.
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 # Constructor.
 sub new {
@@ -48,6 +49,11 @@ sub new {
 		'ysize' => $self->{'height'},
 	);
 
+	# Check type.
+	if (defined $self->{'type'}) {
+		$self->_check_type($self->{'type'});
+	}
+
 	# Object.
 	return $self;
 }
@@ -68,9 +74,6 @@ sub create {
 		if ($suffix eq 'jpg') {
 			$suffix = 'jpeg';
 		}
-
-		# Check type.
-		$self->_check_type($suffix);
 	} else {
 		$suffix = $self->{'type'};
 	}
@@ -117,7 +120,7 @@ sub _check_type {
 	if (none { $type eq $_ } ('bmp', 'gif', 'jpeg', 'png',
 		'pnm', 'raw', 'sgi', 'tga', 'tiff')) {
 
-		err "Suffix '$type' doesn't supported.";
+		err "Image type '$type' doesn't supported."
 	}
 
 	return;
@@ -175,6 +178,16 @@ Image::Checkerboard - Image generator for checkboards.
 =item * C<type>
 
  Image type.
+ Possible types are:
+ - bmp
+ - gif
+ - jpeg
+ - png
+ - pnm
+ - raw
+ - sgi
+ - tga
+ - tiff
  Default value is 'bmp'.
 
 =item * C<width>
@@ -204,10 +217,10 @@ Image::Checkerboard - Image generator for checkboards.
  create():
          Cannot write file to '$path'.",
 	         Error, %s
-         Suffix '%s' doesn't supported.
+         Image type '%s' doesn't supported.
 
  type():
-         Suffix '%s' doesn't supported.
+         Image type '%s' doesn't supported.
 
 
 =head1 EXAMPLE
@@ -241,7 +254,7 @@ Image::Checkerboard - Image generator for checkboards.
 =begin html
 
 <a href="https://raw.githubusercontent.com/tupinek/Image-Checkerboard/master/images/ex1.png">
-  <img src="https://raw.githubusercontent.com/tupinek/Image-Checkerboard/master/images/ex1.png" alt="Generated image" width="300px" height="300px" />
+  <img src="https://raw.githubusercontent.com/tupinek/Image-Checkerboard/master/images/ex1.png" alt="Generated image" width="533px" height="300px" />
 </a>
 
 =end html
@@ -255,8 +268,17 @@ L<Imager::Fill>.
 
 =head1 SEE ALSO
 
-L<Image::Random>,
-L<Image::Select>.
+=over
+
+=item L<Image::Random>
+
+Perl class for creating random image.
+
+=item L<Image::Select>
+
+Perl class for creating random image.
+
+=back
 
 =head1 REPOSITORY
 
@@ -270,11 +292,11 @@ L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
- © 2012-2014 Michal Špaček
+ © 2012-2015 Michal Špaček
  BSD 2-Clause License
 
 =head1 VERSION
 
-0.02
+0.03
 
 =cut
